@@ -12,12 +12,8 @@ namespace stan {
 
     statement::statement(const nil& st) : statement_(st) { }
 
-    statement::statement(const assignment& st) : statement_(st) { }
-
     statement::statement(const assgn& st) : statement_(st) { }
 
-    statement::statement(const compound_assignment& st) : statement_(st) { }
-
     statement::statement(const sample& st) : statement_(st) { }
 
     statement::statement(const increment_log_prob_statement& st)
@@ -30,6 +26,10 @@ namespace stan {
 
     statement::statement(const for_statement& st) : statement_(st) { }
 
+    statement::statement(const for_array_statement& st) : statement_(st) { }
+
+    statement::statement(const for_matrix_statement& st) : statement_(st) { }
+
     statement::statement(const while_statement& st) : statement_(st) { }
 
     statement::statement(const break_continue_statement& st)
