@@ -65,6 +65,16 @@ namespace stan {
        */
       bool is_local() const;
 
+      /**
+       * Flags local scopes which permit parameter variables.
+       * Allows local blocks in functions, transfromed parameter,
+       * and model blocks; disallows local blocks in transformed data
+       * and generated quantities program blocks.
+       *
+       * @return true for local parameter origin block types
+       */
+      bool local_allows_var() const;
+
       /**
        * Flags scopes where parameter variables are declared,
        * i.e., top-level of parameter or transformed parameter block.
