@@ -9,22 +9,18 @@ namespace stan {
 
    /**
      * Generate correct C++ type for expressions which contain a Stan
-     * <code>real</code> variable according to context in which
+     * <code>real</code> variable according to scope in which
      * expression is used and expression contents.
      *
      * @param[in] var_scope expression origin block
-     * @param[in] has_var  does expression contains a variable?
-     * @param[in] is_var_context true when in auto-diff context
+     * @param[in] has_var does expression contains a variable?
      * @param[in,out] o generated typename
      */
     void generate_real_var_type(const scope& var_scope,
                                 bool has_var,
-                                bool is_var_context,
                                 std::ostream& o) {
-      if (var_scope.fun())
-        o << "fun_scalar_t__";
-      else if (is_var_context && has_var)
-        o << "T__";
+      if (var_scope.fun() || has_var)
+        o << "local_scalar_t__";
       else
         o << "double";
     }
