@@ -6,14 +6,12 @@
 #include <stan/math/prim/scal/fun/square.hpp>
 
 namespace stan {
-  namespace math {
+namespace math {
 
-    template <typename T>
-    inline
-    fvar<T>
-    inv(const fvar<T>& x) {
-      return fvar<T>(1 / x.val_, -x.d_ / square(x.val_));
-    }
-  }
+template <typename T>
+inline fvar<T> inv(const fvar<T>& x) {
+  return fvar<T>(1 / x.val_, -x.d_ / square(x.val_));
 }
+}  // namespace math
+}  // namespace stan
 #endif
